==> qmmp-0.7.5.tar.bz2: qmmp-0.7.5/src/plugins/Input/opus/translations/opus_plugin_he.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="he_IL">
<context>
    <name>DecoderOpusFactory</name>
    <message>
        <location filename="../decoderopusfactory.cpp" line="48"/>
        <source>Opus Plugin</source>
        <translation>תוספת Opus</translation>
    </message>
    <message>
        <location filename="../decoderopusfactory.cpp" line="51"/>
        <source>Ogg Opus Files</source>
        <translation>תוספת Ogg Opus</translation>
    </message>
    <message>
        <location filename="../decoderopusfactory.cpp" line="122"/>
        <source>About Opus Audio Plugin</source>
        <translation>אודות תוספת שמע Opus</translation>
    </message>
    <message>
        <location filename="../decoderopusfactory.cpp" line="123"/>
        <source>Qmmp Opus Audio Plugin</source>
        <translation>תוספת שמע Opus ‏Qmmp</translation>
    </message>
    <message>
        <location filename="../decoderopusfactory.cpp" line="124"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>חוברה על ידי: Ilya Kotov ‫&lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
    <message>
        <location filename="../decoderopusfactory.cpp" line="125"/>
        <source>This plugin includes code from TagLib library</source>
        <translation>תוספת זו כוללת קוד מהספרייה TagLib</translation>
    </message>
</context>
<context>
    <name>OpusMetaDataModel</name>
    <message>
        <location filename="../opusmetadatamodel.cpp" line="51"/>
        <source>Length</source>
        <translation>אריכות</translation>
    </message>
    <message>
        <location filename="../opusmetadatamodel.cpp" line="52"/>
        <source>Sample rate</source>
        <translation>שיעור דגימה</translation>
    </message>
    <message>
        <location filename="../opusmetadatamodel.cpp" line="52"/>
        <source>Hz</source>
        <translation>הרץ</translation>
    </message>
    <message>
        <location filename="../opusmetadatamodel.cpp" line="53"/>
        <source>Channels</source>
        <translation>ערוצים</translation>
    </message>
    <message>
        <location filename="../opusmetadatamodel.cpp" line="54"/>
        <source>Bitrate</source>
        <translation>שיעור סיביות</translation>
    </message>
    <message>
        <location filename="../opusmetadatamodel.cpp" line="54"/>
        <source>kbps</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../opusmetadatamodel.cpp" line="55"/>
        <source>File size</source>
        <translation>גודל קובץ</translation>
    </message>
    <message>
        <location filename="../opusmetadatamodel.cpp" line="55"/>
        <source>KB</source>
        <translation>ק״ב</translation>
    </message>
</context>
</TS>

==> qmmp_0.8.1.orig.tar.bz2: qmmp-0.8.1/src/plugins/Input/opus/translations/opus_plugin_he.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="he_IL">
<context>
    <name>DecoderOpusFactory</name>
    <message>
        <location filename="../decoderopusfactory.cpp" line="48"/>
        <source>Opus Plugin</source>
        <translation>תוספת Opus</translation>
    </message>
    <message>
        <location filename="../decoderopusfactory.cpp" line="51"/>
        <source>Ogg Opus Files</source>
        <translation>תוספת Ogg Opus</translation>
    </message>
    <message>
        <location filename="../decoderopusfactory.cpp" line="122"/>
        <source>About Opus Audio Plugin</source>
        <translation>אודות תוספת שמע Opus</translation>
    </message>
    <message>
        <location filename="../decoderopusfactory.cpp" line="123"/>
        <source>Qmmp Opus Audio Plugin</source>
        <translation>תוספת שמע Opus של Qmmp</translation>
    </message>
    <message>
        <location filename="../decoderopusfactory.cpp" line="124"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>חוברה על ידי: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;‎</translation>
    </message>
    <message>
        <location filename="../decoderopusfactory.cpp" line="125"/>
        <source>This plugin includes code from TagLib library</source>
        <translation>תוספת זו כוללת קוד מתוך הספרייה TagLib</translation>
    </message>
</context>
<context>
    <name>OpusMetaDataModel</name>
    <message>
        <location filename="../opusmetadatamodel.cpp" line="51"/>
        <source>Length</source>
        <translation>אריכות</translation>
    </message>
    <message>
        <location filename="../opusmetadatamodel.cpp" line="52"/>
        <source>Sample rate</source>
        <translation>שיעור דגימה</translation>
    </message>
    <message>
        <location filename="../opusmetadatamodel.cpp" line="52"/>
        <source>Hz</source>
        <translation>הרץ</translation>
    </message>
    <message>
        <location filename="../opusmetadatamodel.cpp" line="53"/>
        <source>Channels</source>
        <translation>ערוצים</translation>
    </message>
    <message>
        <location filename="../opusmetadatamodel.cpp" line="54"/>
        <source>Bitrate</source>
        <translation>שיעור סיביות</translation>
    </message>
    <message>
        <location filename="../opusmetadatamodel.cpp" line="54"/>
        <source>kbps</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../opusmetadatamodel.cpp" line="55"/>
        <source>File size</source>
        <translation>גודל קובץ</translation>
    </message>
    <message>
        <location filename="../opusmetadatamodel.cpp" line="55"/>
        <source>KB</source>
        <translation>ק״ב</translation>
    </message>
</context>
</TS>
